==> multiway-0.0.20.tgz: package/es/MwSearchTable/index.js <==
var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
var __spreadArray = this && this.__spreadArray || function (to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
    if (ar || !(i in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i);
      ar[i] = from[i];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
};
import React, { useRef, forwardRef, useImperativeHandle, useState, useMemo, useEffect } from 'react';
import MwSearch from '../MwSearch';
import MwForm from '../MwForm';
import MwTable from '../MwTable';
import MwDialogForm from '../MwDialogForm';
import useSelection from './use/useSelection';
import { isObj, omitObj } from '../utils';
import { getDefaultValue } from '../MwForm';
import { Space } from 'antd';
import { getActionProps } from '../MwAction';
import useExtraBtn, { setSearchTableExtraDefaultValue } from './use/useExtraBtn';
import MwButton from '../MwButton';
import { MwSearchTableContext } from './context';
import { convertChildrenToField } from '../MwFields/convertFields';
import classNames from 'classnames';
import "./mw-search-table.css";
/**
 * 转化并过滤成 mw-search 能用的 fields
 * @param fields 查询表格的 fields
 */
var getSearchFields = function getSearchFields(fields) {
  var searchFields = [];
  var moreSearchFields = [];
  fields.filter(function (field) {
    return isObj(field.search) || field.search === true;
  }).forEach(function (field) {
    var search = typeof field.search === 'boolean' ? {} : field.search;
    if (!search) {
      return {
        title: '配置有误',
        key: 'xxx',
        type: 'input'
      };
    }
    var searchField = __assign({
      title: field.title,
      key: search.key || field.key || '',
      type: field.type || 'input',
      options: field.options || [],
      mode: field.mode
    }, search);
    if (field.children) {
      searchField.children = field.children;
    }
    if (searchField.position === 'more') {
      moreSearchFields.push(searchField);
    } else {
      searchFields.push(searchField);
    }
  });
  return {
    searchFields: searchFields,
    moreSearchFields: moreSearchFields
  };
};
/**
 * 过滤获得配置项
 *
 * 1、生成基础 table 需要的 fields
 * 2、添加 options (如果有的话)
 *
 * @param fields 配置项
 */
var getTableFields = function getTableFields(fields) {
  return fields.map(function (field) {
    var table = typeof field.table === 'boolean' ? {} : field.table;
    // false 表示表格隐藏
    if (field.table === false) {
      table = {
        hidden: true
      };
    }
    var tableField = __assign(__assign(__assign({}, omitObj(field, 'table')), {
      title: field.title,
      key: field.key
    }), table);
    return tableField;
  });
};
/**
 * 获取默认过滤值
 * @param fields 当前的表格配置项
 * @returns AnyKeyProps
 */
var getFiltersDefaultValue = function getFiltersDefaultValue(fields) {
  var filtersValue = {};
  fields.forEach(function (field) {
    if (field.key && field.defaultFilterValue && field.defaultFilterValue !== 0) {
      filtersValue[field.key] = field.defaultFilterValue;
    }
  });
  return filtersValue;
};
/**
 * 获取默认排序值
 * @param fields 当前的表格配置项
 * @returns Array<{ key: string, order: 'ascend' | 'descend' }>
 */
var getSortsDefaultValue = function getSortsDefaultValue(fields) {
  var sorts = [];
  // 排序是否带了先后顺序
  var hasSortOrder = false;
  fields.forEach(function (field) {
    if (field.key && field.defaultSortsValue) {
      var item = {
        key: field.key,
        order: field.defaultSortsValue
      };
      // 如果携带了 sortOrder
      if (field.sortOrder >= 0) {
        hasSortOrder = true;
        item.index = field.sortOrder;
      }
      sorts.push(item);
    }
  });
  // 携带了排序值需要排序一遍
  if (hasSortOrder) {
    sorts.sort(function (a, b) {
      return (a.index || 9999) - (b.index || 9999);
    });
    // 删除 index 排序值
    sorts = sorts.map(function (item) {
      return {
        key: item.key,
        order: item.order
      };
    });
  }
  return sorts;
};
/**
 * 判断该节点是否只出现在底部
 * @param node MwAction 按钮
 */
var isFooterActionOnly = function isFooterActionOnly(node) {
  if (!node || !node.props) {
    return false;
  }
  var props = getActionProps(node.props, {});
  return props.tableFooterExtraOnly === true;
};
/**
 * 获取表格底部以及右侧 MwAction 按钮
 * @param node MwAction 按钮
 */
var getTableActionBtns = function getTableActionBtns(children) {
  /** 右侧按钮 */
  var footerActions = [];
  /** 底部按钮 */
  var rightActions = [];
  if (Array.isArray(children)) {
    children.forEach(function (node) {
      if (isFooterActionOnly(node)) {
        footerActions.push(node);
      } else if (node) {
        rightActions.push(node);
      }
    });
  } else {
    if (isFooterActionOnly(children)) {
      footerActions.push(children);
    } else if (children) {
      rightActions.push(children);
    }
  }
  return {
    rightActions: rightActions,
    footerActions: footerActions
  };
};
/** 初始化查询表格配置 */
export var setSearchTableDefaultValue = function setSearchTableDefaultValue(config) {
  // 初始化扩展列
  setSearchTableExtraDefaultValue(config);
};
export default /*#__PURE__*/forwardRef(function MwSearchTable(props, ref) {
  var className = props.className,
    rowClassName = props.rowClassName,
    originFields = props.fields,
    api = props.api,
    deleteApi = props.deleteApi,
    children = props.children,
    data = props.data,
    title = props.title,
    ctrl = props.ctrl,
    selectionType = props.selectionType,
    onSelectionChange = props.onSelectionChange,
    rowKey = props.rowKey,
    dialogFormExtend = props.dialogFormExtend,
    scrollX = props.scrollX,
    height = props.height,
    filterData = props.filterData,
    beforeSearch = props.beforeSearch,
    selectShowKey = props.selectShowKey,
    onExpand = props.onExpand,
    center = props.center,
    onLoad = props.onLoad,
    searchVisible = props.searchVisible,
    tableExtend = props.tableExtend,
    pagination = props.pagination,
    btnBefore = props.btnBefore,
    extendSearchParams = props.extendSearchParams,
    before = props.before,
    defaultExtra = props.defaultExtra,
    after = props.after,
    editMode = props.editMode,
    autoload = props.autoload,
    rowSelection = props.rowSelection,
    searchExtend = props.searchExtend,
    onParamsChange = props.onParamsChange,
    tableHeader = props.tableHeader,
    compact = props.compact,
    useOriginPagination = props.useOriginPagination;
  var fields = useMemo(function () {
    var childrenFields = convertChildrenToField(children);
    return __spreadArray(__spreadArray([], originFields || [], true), childrenFields, true);
  }, [originFields, children]);
  /** form 控制 */
  var formRef = useRef();
  /** table 控制 */
  var tableRef = useRef();
  /** search 控制 */
  var searchRef = useRef();
  /** search 控制 */
  var moreSearchRef = useRef();
  /** 查询项 */
  var _a = getSearchFields(fields),
    searchFields = _a.searchFields,
    moreSearchFields = _a.moreSearchFields;
  /** 列表项 */
  var _b = useState(getTableFields(fields)),
    tableFields = _b[0],
    setTableFields = _b[1];
  /** 使用勾选 */
  var _c = useSelection({
      rowKey: rowKey,
      selectionType: selectionType,
      onSelectionChange: onSelectionChange,
      selectShowKey: selectShowKey,
      rowSelection: rowSelection
    }),
    header = _c.header,
    message = _c.message,
    tableRowSelection = _c.tableRowSelection,
    selection = _c.selection,
    _clearSelection = _c.clearSelection,
    setSelection = _c.setSelection,
    addSelection = _c.addSelection,
    removeSelection = _c.removeSelection;
  /** action 展示，底部 or 右侧 */
  var _d = getTableActionBtns(children),
    footerActions = _d.footerActions,
    rightActions = _d.rightActions;
  var _e = useState([]),
    editTableRow = _e[0],
    setEditTableRows = _e[1];
  var _f = useExtraBtn(tableRef, searchRef, tableFields, setTableFields, props),
    extraBtns = _f.extraBtns,
    size = _f.size,
    isEnter = _f.isEnter,
    setDefaultField = _f.setDefaultField;
  var doLayout = function doLayout() {
    // 刷新表格
    setTableFields(getTableFields(fields));
    // 设置顶部刷新
    if (searchRef.current && typeof searchRef.current.rezise === 'function') {
      searchRef.current.rezise();
    }
  };
  useEffect(function () {
    doLayout();
  }, [fields, isEnter]);
  /** 获取查询参数 */
  var getSearchParams = function getSearchParams() {
    var _a, _b;
    // 更多查询数据
    var moreSearchValues = ((_a = moreSearchRef.current) === null || _a === void 0 ? void 0 : _a.getFieldsValue()) || {};
    // 头顶查询数据
    var searchValues = ((_b = searchRef.current) === null || _b === void 0 ? void 0 : _b.getFieldsValue()) || {};
    return __assign(__assign({}, moreSearchValues), searchValues);
  };
  /** 查询完成，刷新列表 */
  var onConfirm = function onConfirm() {
    // 合并查询
    tableRef.current.reset(getSearchParams());
  };
  /** 暴露方法 */
  useImperativeHandle(ref, function () {
    return {
      /**
       * 刷新页面
       */
      refresh: function refresh() {
        tableRef.current.refresh();
      },
      /**
       * 回到第一页，刷新页面
       */
      reset: function reset() {
        // 跟点击【查询】逻辑一致
        onConfirm();
      },
      /**
       * 清空选项
       */
      clearSelection: function clearSelection() {
        _clearSelection();
      },
      /**
       * 获取 search 对象
       */
      getSearchRef: function getSearchRef() {
        return searchRef.current;
      },
      /**
       * 获取 moreSearch 对象，表格右侧查询框
       */
      getMoreSearchRef: function getMoreSearchRef() {
        return moreSearchRef.current;
      },
      /**
       * 获取已经选中的对象
       */
      getSelection: function getSelection() {
        return selection;
      },
      /**
       * 设置选中的行
       */
      setSelection: setSelection,
      /**
       * 添加选中的行
       */
      addSelection: addSelection,
      /**
       * 刷新布局
       */
      doLayout: doLayout,
      /**
       * 获取表格数据
       */
      getTableData: function getTableData() {
        return tableRef.current.getTableData();
      },
      /**
       * 设置表格数据
       */
      setTableData: function setTableData(tableData) {
        return tableRef.current.setTableData(tableData);
      },
      /**
       * 清空过滤
       * @param keys
       */
      clearFilters: function clearFilters(keys) {
        if (keys === void 0) {
          keys = [];
        }
        return tableRef.current.clearFilters(keys);
      },
      /**
       * 设置过滤值
       * @param filters 需要设置的过滤值，{ key: value } 格式
       */
      setFiltersValue: function setFiltersValue(filters) {
        return tableRef.current.setFiltersValue(filters);
      },
      /**
       * 设置排序值
       * @param sorts [{ key, order }] 组成格式
       */
      setSortsValue: function setSortsValue(sorts) {
        return tableRef.current.setSortsValue(sorts);
      },
      /**
       * 清空排序
       * @param keys
       */
      clearSorts: function clearSorts(keys) {
        if (keys === void 0) {
          keys = [];
        }
        return tableRef.current.clearSorts(keys);
      },
      /** 获取请求前参数 */
      getApiParams: function getApiParams() {
        return tableRef.current.getApiParams();
      },
      /**
       * 根据 id 删除某一行数据
       */
      deleteRowByKey: function deleteRowByKey(key) {
        tableRef.current.deleteRowByKey(key);
      },
      getFromRef: function getFromRef() {
        return formRef.current;
      },
      /**
       * 新增一行数据
       * @param row 新增的数据
       * @param type 新增在前面还是后面
       */
      addRow: function addRow(record, type) {
        if (type === void 0) {
          type = 'after';
        }
        tableRef.current.addRow(record, type);
      },
      /**
       * 获取编辑表单的每一行的form
       */
      getEditTableRowForm: function getEditTableRowForm() {
        return editTableRow;
      },
      setPaginitionValue: function setPaginitionValue(paginition) {
        tableRef.current.setPaginitionValue(paginition);
      }
    };
  });
  var tableProps = {
    ref: tableRef,
    rowSelection: tableRowSelection,
    api: api,
    size: size,
    data: data,
    title: title,
    ctrl: ctrl,
    rowKey: rowKey,
    scrollX: scrollX,
    height: height,
    filterData: filterData,
    beforeSearch: beforeSearch,
    onExpand: onExpand,
    onLoad: onLoad,
    tableExtend: tableExtend,
    pagination: pagination,
    defaultFiltersValue: getFiltersDefaultValue(tableFields),
    defaultSortsValue: getSortsDefaultValue(tableFields),
    defaultSearchValue: getDefaultValue(__spreadArray(__spreadArray([], searchFields, true), moreSearchFields, true)),
    btnBefore: btnBefore,
    editMode: editMode,
    extendSearchParams: extendSearchParams,
    autoload: autoload,
    onParamsChange: onParamsChange,
    tableHeader: tableHeader,
    getSearchParams: getSearchParams,
    useOriginPagination: useOriginPagination
  };
  /** 表格子元素 */
  var tableChildren = useMemo(function () {
    var children = [];
    if (moreSearchFields && moreSearchFields.length) {
      children.push( /*#__PURE__*/React.createElement(MwForm, {
        className: "mw-search-table-more",
        key: "mw-search-table-more",
        ref: moreSearchRef,
        fields: moreSearchFields,
        onConfirm: onConfirm
      }, /*#__PURE__*/React.createElement(MwButton, {
        className: "mw-search-table-more-submit",
        htmlType: "submit"
      })));
    }
    if (rightActions && rightActions.length) {
      children.push(rightActions);
    }
    if (extraBtns) {
      children.push(extraBtns);
    }
    if (children.length === 1) {
      return children[0];
    }
    return children.length ? children : null;
  }, [moreSearchRef, moreSearchFields, onConfirm, rightActions, extraBtns]);
  useEffect(function () {
    defaultExtra && setDefaultField(defaultExtra);
  }, []);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames('mw-search-table', isEnter && 'full', compact && 'compact')
  }, /*#__PURE__*/React.createElement(MwSearchTableContext.Provider, {
    value: {
      formRef: formRef,
      tableRef: tableRef,
      selection: selection,
      deleteApi: deleteApi,
      rowKey: rowKey,
      setSelection: setSelection,
      clearSelection: _clearSelection,
      addSelection: addSelection,
      removeSelection: removeSelection,
      searchTableRef: ref,
      editTableRow: editTableRow,
      setEditTableRow: function setEditTableRow(list) {
        setEditTableRows(function (origin) {
          return __spreadArray(__spreadArray([], origin, true), list, true);
        });
      }
    }
  }, before, searchVisible !== false && searchFields.length > 0 ? /*#__PURE__*/React.createElement(MwSearch, __assign({
    ref: searchRef,
    fields: searchFields,
    onConfirm: onConfirm
  }, searchExtend)) : null, center, dialogFormExtend ? /*#__PURE__*/React.createElement(MwDialogForm, __assign({
    ref: formRef,
    dialogOnly: true
  }, dialogFormExtend), children) : null, /*#__PURE__*/React.createElement(MwTable, __assign({}, tableProps, {
    fields: tableFields,
    header: header
  }), tableChildren), selection.length && footerActions.length ? /*#__PURE__*/React.createElement("div", {
    className: "mw-search-table-footer-actions"
  }, message, /*#__PURE__*/React.createElement(Space, null, footerActions)) : null, after));
});

==> multiway-0.0.25.tgz: package/es/MwSearchTable/index.js <==
var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
var __spreadArray = this && this.__spreadArray || function (to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
    if (ar || !(i in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i);
      ar[i] = from[i];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
};
import React, { useRef, forwardRef, useImperativeHandle, useState, useMemo, useEffect } from 'react';
import MwSearch from '../MwSearch';
import MwForm from '../MwForm';
import MwTable from '../MwTable';
import MwDialogForm from '../MwDialogForm';
import useSelection from './use/useSelection';
import { isObj, omitObj, optionObj } from '../utils';
import { getDefaultValue } from '../MwForm';
import { Space } from 'antd';
import { getActionProps } from '../MwAction';
import useExtraBtn, { setSearchTableExtraDefaultValue } from './use/useExtraBtn';
import MwButton from '../MwButton';
import { MwSearchTableContext } from './context';
import { convertChildrenToField } from '../MwFields/convertFields';
import classNames from 'classnames';
import "./mw-search-table.css";
/**
 * 转化并过滤成 mw-search 能用的 fields
 * @param fields 查询表格的 fields
 */
var getSearchFields = function getSearchFields(fields) {
  var searchFields = [];
  var moreSearchFields = [];
  fields.filter(function (field) {
    return isObj(field.search) || field.search === true;
  }).forEach(function (field) {
    var _a;
    var search = typeof field.search === 'boolean' ? {} : field.search;
    if (!search) {
      return {
        title: '配置有误',
        key: 'xxx',
        type: 'input'
      };
    }
    var searchField = __assign(__assign({
      title: field.title,
      key: search.key || field.key || '',
      type: field.type || 'input',
      options: field.options || [],
      mode: field.mode
    }, search), optionObj(field, ((_a = field === null || field === void 0 ? void 0 : field.userKey) === null || _a === void 0 ? void 0 : _a.length) ? __spreadArray([], field === null || field === void 0 ? void 0 : field.userKey, true) : []));
    if (field.children) {
      searchField.children = field.children;
    }
    if (searchField.position === 'more') {
      moreSearchFields.push(searchField);
    } else {
      searchFields.push(searchField);
    }
  });
  return {
    searchFields: searchFields,
    moreSearchFields: moreSearchFields
  };
};
/**
 * 过滤获得配置项
 *
 * 1、生成基础 table 需要的 fields
 * 2、添加 options (如果有的话)
 *
 * @param fields 配置项
 */
var getTableFields = function getTableFields(fields) {
  return fields.map(function (field) {
    var table = typeof field.table === 'boolean' ? {} : field.table;
    // false 表示表格隐藏
    if (field.table === false) {
      table = {
        hidden: true
      };
    }
    var tableField = __assign(__assign(__assign({}, omitObj(field, 'table')), {
      title: field.title,
      key: field.key
    }), table);
    return tableField;
  });
};
/**
 * 获取默认过滤值
 * @param fields 当前的表格配置项
 * @returns AnyKeyProps
 */
var getFiltersDefaultValue = function getFiltersDefaultValue(fields) {
  var filtersValue = {};
  fields.forEach(function (field) {
    if (field.key && field.defaultFilterValue && field.defaultFilterValue !== 0) {
      filtersValue[field.key] = field.defaultFilterValue;
    }
  });
  return filtersValue;
};
/**
 * 获取默认排序值
 * @param fields 当前的表格配置项
 * @returns Array<{ key: string, order: 'ascend' | 'descend' }>
 */
var getSortsDefaultValue = function getSortsDefaultValue(fields) {
  var sorts = [];
  // 排序是否带了先后顺序
  var hasSortOrder = false;
  fields.forEach(function (field) {
    if (field.key && field.defaultSortsValue) {
      var item = {
        key: field.key,
        order: field.defaultSortsValue
      };
      // 如果携带了 sortOrder
      if (field.sortOrder >= 0) {
        hasSortOrder = true;
        item.index = field.sortOrder;
      }
      sorts.push(item);
    }
  });
  // 携带了排序值需要排序一遍
  if (hasSortOrder) {
    sorts.sort(function (a, b) {
      return (a.index || 9999) - (b.index || 9999);
    });
    // 删除 index 排序值
    sorts = sorts.map(function (item) {
      return {
        key: item.key,
        order: item.order
      };
    });
  }
  return sorts;
};
/**
 * 判断该节点是否只出现在底部
 * @param node MwAction 按钮
 */
var isFooterActionOnly = function isFooterActionOnly(node) {
  if (!node || !node.props) {
    return false;
  }
  var props = getActionProps(node.props, {});
  return props.tableFooterExtraOnly === true;
};
/**
 * 获取表格底部以及右侧 MwAction 按钮
 * @param node MwAction 按钮
 */
var getTableActionBtns = function getTableActionBtns(children) {
  /** 右侧按钮 */
  var footerActions = [];
  /** 底部按钮 */
  var rightActions = [];
  if (Array.isArray(children)) {
    children.forEach(function (node) {
      if (isFooterActionOnly(node)) {
        footerActions.push(node);
      } else if (node) {
        rightActions.push(node);
      }
    });
  } else {
    if (isFooterActionOnly(children)) {
      footerActions.push(children);
    } else if (children) {
      rightActions.push(children);
    }
  }
  return {
    rightActions: rightActions,
    footerActions: footerActions
  };
};
/** 初始化查询表格配置 */
export var setSearchTableDefaultValue = function setSearchTableDefaultValue(config) {
  // 初始化扩展列
  setSearchTableExtraDefaultValue(config);
};
export default /*#__PURE__*/forwardRef(function MwSearchTable(props, ref) {
  var className = props.className,
    rowClassName = props.rowClassName,
    originFields = props.fields,
    api = props.api,
    deleteApi = props.deleteApi,
    children = props.children,
    data = props.data,
    title = props.title,
    ctrl = props.ctrl,
    selectionType = props.selectionType,
    onSelectionChange = props.onSelectionChange,
    rowKey = props.rowKey,
    dialogFormExtend = props.dialogFormExtend,
    scrollX = props.scrollX,
    height = props.height,
    filterData = props.filterData,
    beforeSearch = props.beforeSearch,
    selectShowKey = props.selectShowKey,
    onExpand = props.onExpand,
    center = props.center,
    onLoad = props.onLoad,
    searchVisible = props.searchVisible,
    tableExtend = props.tableExtend,
    pagination = props.pagination,
    btnBefore = props.btnBefore,
    extendSearchParams = props.extendSearchParams,
    before = props.before,
    defaultExtra = props.defaultExtra,
    after = props.after,
    editMode = props.editMode,
    autoload = props.autoload,
    rowSelection = props.rowSelection,
    searchExtend = props.searchExtend,
    onParamsChange = props.onParamsChange,
    tableHeader = props.tableHeader,
    compact = props.compact,
    useOriginPagination = props.useOriginPagination;
  var fields = useMemo(function () {
    var childrenFields = convertChildrenToField(children);
    return __spreadArray(__spreadArray([], originFields || [], true), childrenFields, true);
  }, [originFields, children]);
  /** form 控制 */
  var formRef = useRef();
  /** table 控制 */
  var tableRef = useRef();
  /** search 控制 */
  var searchRef = useRef();
  /** search 控制 */
  var moreSearchRef = useRef();
  /** 查询项 */
  var _a = getSearchFields(fields),
    searchFields = _a.searchFields,
    moreSearchFields = _a.moreSearchFields;
  /** 列表项 */
  var _b = useState(getTableFields(fields)),
    tableFields = _b[0],
    setTableFields = _b[1];
  /** 使用勾选 */
  var _c = useSelection({
      rowKey: rowKey,
      selectionType: selectionType,
      onSelectionChange: onSelectionChange,
      selectShowKey: selectShowKey,
      rowSelection: rowSelection
    }),
    header = _c.header,
    message = _c.message,
    tableRowSelection = _c.tableRowSelection,
    selection = _c.selection,
    _clearSelection = _c.clearSelection,
    setSelection = _c.setSelection,
    addSelection = _c.addSelection,
    removeSelection = _c.removeSelection;
  /** action 展示，底部 or 右侧 */
  var _d = getTableActionBtns(children),
    footerActions = _d.footerActions,
    rightActions = _d.rightActions;
  var _e = useState([]),
    editTableRow = _e[0],
    setEditTableRows = _e[1];
  var _f = useExtraBtn(tableRef, searchRef, tableFields, setTableFields, props),
    extraBtns = _f.extraBtns,
    size = _f.size,
    isEnter = _f.isEnter,
    setDefaultField = _f.setDefaultField;
  var doLayout = function doLayout() {
    // 刷新表格
    setTableFields(getTableFields(fields));
    // 设置顶部刷新
    if (searchRef.current && typeof searchRef.current.rezise === 'function') {
      searchRef.current.rezise();
    }
  };
  useEffect(function () {
    doLayout();
  }, [fields, isEnter]);
  /** 获取查询参数 */
  var getSearchParams = function getSearchParams() {
    var _a, _b;
    // 更多查询数据
    var moreSearchValues = ((_a = moreSearchRef.current) === null || _a === void 0 ? void 0 : _a.getFieldsValue()) || {};
    // 头顶查询数据
    var searchValues = ((_b = searchRef.current) === null || _b === void 0 ? void 0 : _b.getFieldsValue()) || {};
    return __assign(__assign({}, moreSearchValues), searchValues);
  };
  /** 查询完成，刷新列表 */
  var onConfirm = function onConfirm() {
    // 合并查询
    tableRef.current.reset(getSearchParams());
  };
  /** 暴露方法 */
  useImperativeHandle(ref, function () {
    return {
      /**
       * 刷新页面
       */
      refresh: function refresh() {
        tableRef.current.refresh();
      },
      /**
       * 回到第一页，刷新页面
       */
      reset: function reset() {
        // 跟点击【查询】逻辑一致
        onConfirm();
      },
      /**
       * 清空选项
       */
      clearSelection: function clearSelection() {
        _clearSelection();
      },
      /**
       * 获取 search 对象
       */
      getSearchRef: function getSearchRef() {
        return searchRef.current;
      },
      /**
       * 获取 moreSearch 对象，表格右侧查询框
       */
      getMoreSearchRef: function getMoreSearchRef() {
        return moreSearchRef.current;
      },
      /**
       * 获取已经选中的对象
       */
      getSelection: function getSelection() {
        return selection;
      },
      /**
       * 设置选中的行
       */
      setSelection: setSelection,
      /**
       * 添加选中的行
       */
      addSelection: addSelection,
      /**
       * 刷新布局
       */
      doLayout: doLayout,
      /**
       * 获取表格数据
       */
      getTableData: function getTableData() {
        return tableRef.current.getTableData();
      },
      /**
       * 设置表格数据
       */
      setTableData: function setTableData(tableData) {
        return tableRef.current.setTableData(tableData);
      },
      /**
       * 清空过滤
       * @param keys
       */
      clearFilters: function clearFilters(keys) {
        if (keys === void 0) {
          keys = [];
        }
        return tableRef.current.clearFilters(keys);
      },
      /**
       * 设置过滤值
       * @param filters 需要设置的过滤值，{ key: value } 格式
       */
      setFiltersValue: function setFiltersValue(filters) {
        return tableRef.current.setFiltersValue(filters);
      },
      /**
       * 设置排序值
       * @param sorts [{ key, order }] 组成格式
       */
      setSortsValue: function setSortsValue(sorts) {
        return tableRef.current.setSortsValue(sorts);
      },
      /**
       * 清空排序
       * @param keys
       */
      clearSorts: function clearSorts(keys) {
        if (keys === void 0) {
          keys = [];
        }
        return tableRef.current.clearSorts(keys);
      },
      /** 获取请求前参数 */
      getApiParams: function getApiParams() {
        return tableRef.current.getApiParams();
      },
      /**
       * 根据 id 删除某一行数据
       */
      deleteRowByKey: function deleteRowByKey(key) {
        tableRef.current.deleteRowByKey(key);
      },
      getFromRef: function getFromRef() {
        return formRef.current;
      },
      /**
       * 新增一行数据
       * @param row 新增的数据
       * @param type 新增在前面还是后面
       */
      addRow: function addRow(record, type) {
        if (type === void 0) {
          type = 'after';
        }
        tableRef.current.addRow(record, type);
      },
      /**
       * 获取编辑表单的每一行的form
       */
      getEditTableRowForm: function getEditTableRowForm() {
        return editTableRow;
      },
      setPaginitionValue: function setPaginitionValue(paginition) {
        tableRef.current.setPaginitionValue(paginition);
      }
    };
  });
  var tableProps = {
    ref: tableRef,
    rowSelection: tableRowSelection,
    api: api,
    size: size,
    data: data,
    title: title,
    ctrl: ctrl,
    rowKey: rowKey,
    scrollX: scrollX,
    height: height,
    filterData: filterData,
    beforeSearch: beforeSearch,
    onExpand: onExpand,
    onLoad: onLoad,
    tableExtend: tableExtend,
    pagination: pagination,
    defaultFiltersValue: getFiltersDefaultValue(tableFields),
    defaultSortsValue: getSortsDefaultValue(tableFields),
    defaultSearchValue: getDefaultValue(__spreadArray(__spreadArray([], searchFields, true), moreSearchFields, true)),
    btnBefore: btnBefore,
    editMode: editMode,
    extendSearchParams: extendSearchParams,
    autoload: autoload,
    onParamsChange: onParamsChange,
    tableHeader: tableHeader,
    getSearchParams: getSearchParams,
    useOriginPagination: useOriginPagination
  };
  /** 表格子元素 */
  var tableChildren = useMemo(function () {
    var children = [];
    if (moreSearchFields && moreSearchFields.length) {
      children.push( /*#__PURE__*/React.createElement(MwForm, {
        className: "mw-search-table-more",
        key: "mw-search-table-more",
        ref: moreSearchRef,
        fields: moreSearchFields,
        onConfirm: onConfirm
      }, /*#__PURE__*/React.createElement(MwButton, {
        className: "mw-search-table-more-submit",
        htmlType: "submit"
      })));
    }
    if (rightActions && rightActions.length) {
      children.push(rightActions);
    }
    if (extraBtns) {
      children.push(extraBtns);
    }
    if (children.length === 1) {
      return children[0];
    }
    return children.length ? children : null;
  }, [moreSearchRef, moreSearchFields, onConfirm, rightActions, extraBtns]);
  useEffect(function () {
    defaultExtra && setDefaultField(defaultExtra);
  }, []);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames('mw-search-table', isEnter && 'full', compact && 'compact')
  }, /*#__PURE__*/React.createElement(MwSearchTableContext.Provider, {
    value: {
      formRef: formRef,
      tableRef: tableRef,
      selection: selection,
      deleteApi: deleteApi,
      rowKey: rowKey,
      setSelection: setSelection,
      clearSelection: _clearSelection,
      addSelection: addSelection,
      removeSelection: removeSelection,
      searchTableRef: ref,
      editTableRow: editTableRow,
      setEditTableRow: function setEditTableRow(list) {
        setEditTableRows(function (origin) {
          return __spreadArray(__spreadArray([], origin, true), list, true);
        });
      }
    }
  }, before, searchVisible !== false && searchFields.length > 0 ? /*#__PURE__*/React.createElement(MwSearch, __assign({
    ref: searchRef,
    fields: searchFields,
    onConfirm: onConfirm
  }, searchExtend)) : null, center, dialogFormExtend ? /*#__PURE__*/React.createElement(MwDialogForm, __assign({
    ref: formRef,
    dialogOnly: true
  }, dialogFormExtend), children) : null, /*#__PURE__*/React.createElement(MwTable, __assign({}, tableProps, {
    fields: tableFields,
    header: header
  }), tableChildren), selection.length && footerActions.length ? /*#__PURE__*/React.createElement("div", {
    className: "mw-search-table-footer-actions"
  }, message, /*#__PURE__*/React.createElement(Space, null, footerActions)) : null, after));
});
